import loading
from loading import *


#player base
class PlayerBase(pygame.sprite.Sprite):
    def __init__(self, locs, fish):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('base.png', alpha = True)
        self.crew_icon, r = load_image('peng-icon.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50
        self.num_fish = fish
        self.num_crew = 10
        self.counter = 0
            

    def draw(self, surf, globex, globey):
        self.counter += 1
        if self.counter >= 250:
            if self.num_crew < 20:
                self.num_crew += 1
            self.counter = 0

        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (self.num_fish*50,
                                 0,
                                 50,50))
        for i in range(0,int(self.num_crew/2)):
            surf.blit(self.crew_icon, (self.rect.left+globex-10+(i*15)-25, self.rect.top + globey-50))
        for i in range(int(self.num_crew/2),self.num_crew):
            surf.blit(self.crew_icon, (self.rect.left+globex-10+(i*15)-(15*int(self.num_crew/2))-25, self.rect.top + globey-25))
#game units

class Player(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('player-small.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50
        self.small_rect = pygame.rect.Rect(0,0,40,40)
        self.small_rect.center = self.rect.center
        self.big_rect = pygame.rect.Rect(0,0,200,200)
        self.big_rect.center = self.rect.center
        self.really_big_rect = pygame.rect.Rect(0,0,400,400)
        self.really_big_rect.center = self.rect.center

        self.hull_health = 50
        self.crew = 15

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0

        self.on_animation = "still"

        #corners = 1,5,9,13
        #verts = 3, 11
        #horzs = 7, 15
        
    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50,
                                     50,50))

    def update(self):
        if self.facing == 1 or self.facing == 5 or self.facing == 9 or self.facing == 13:
            self.small_rect = pygame.rect.Rect(0,0,35,35)
        elif self.facing == 3 or self.facing == 11:
            self.small_rect = pygame.rect.Rect(0,0,25, 45)
        else:
            self.small_rect = pygame.rect.Rect(0,0,45,25)
        self.small_rect.center = self.rect.center
        self.big_rect.center = self.rect.center
        self.really_big_rect.center = self.rect.center
        
        self.master_counter += 1
        if self.master_counter == 3:
            self.master_counter = 0
            self.animation_counter += 1
        if self.animation_counter == 3:
            self.animation_counter = 0


class Herring(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('schoolfish.png', alpha=True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50
        self.rotate_timer = 4
        self.num = random.randint(0,3)
        if self.num >= 4:
            self.num = 3
        self.animation_counter = 0
        self.master_counter = 0

    def draw(self, surf, globex, globey):
        self.master_counter += 1
        if self.master_counter == 3:
            self.animation_counter += 1
            self.master_counter = 0
        if self.animation_counter == 10:
            self.animation_counter = 0
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (self.animation_counter*50,
                                 self.num*50,
                                 50,50))


class Decoy(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('decoy-sub.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50

        self.hull_health = 50

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0

        self.goto = [random.randint(0,40*50-1),random.randint(0,40*50-1)]

    def draw(self, surf, globex, globey):
        f = self.facing
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (f*50,
                                 self.animation_counter*50,
                                 50,50))

    def move(self, rocks):
        for rock in rocks:
            if self.rect.colliderect(rock.rect):
                if self.rect.centerx <= rock.rect.centerx:
                    self.rect.centerx -= 1
                    self.rect.centery += 1
                else:
                    self.rect.centerx += 1
                    self.rect.centery += 1

                if self.rect.centery <= rock.rect.centery:
                    self.rect.centery -= 1
                    self.rect.centerx += 1
                else:
                    self.rect.centery += 1
                    self.rect.centerx += 1
            else:
                pass
            
        if self.goto[0] < self.rect.left:
            if self.goto[1] < self.rect.top:
                self.facing = 13#up-left
            elif self.goto[1] > self.rect.top:
                self.facing = 1#down-left
            else:
                self.facing = 15#left
        elif self.goto[0] > self.rect.left:
            if self.goto[1] < self.rect.top:
                self.facing = 9#up-right
            elif self.goto[1] > self.rect.top:
                self.facing = 5#down-right
            else:
                self.facing = 7#right
        else:
            if self.goto[1] < self.rect.top:
                self.facing = 11#up
            elif self.goto[1] > self.rect.top:
                self.facing = 3#down
            else:pass#pass

        if self.rect.left < self.goto[0]:
            self.rect.left += 1
        elif self.rect.left > self.goto[0]:
            self.rect.left -= 1

        if self.rect.top < self.goto[1]:
            self.rect.top += 1
        elif self.rect.top > self.goto[1]:
            self.rect.top -= 1

        if self.rect.centerx - self.goto[0] <= 50 and self.rect.centerx - self.goto[0] >= -50:
            self.goto = [random.randint(0,40*50-1), random.randint(0,40*50-1)]
        if self.rect.centery - self.goto[1] <= 50 and self.rect.centery - self.goto[1] >= -50:
            self.goto = [random.randint(0,40*50-1), random.randint(0,40*50-1)]
            
    def update(self, rocks):
        self.move(rocks)
                
        self.master_counter += 1
        if self.master_counter == 3: 
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0

            
class RedHerring(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('herring-sub.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50

        self.hull_health = 50

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0

        self.goto = [random.randint(0,40*50-1),random.randint(0,40*50-1)]

    def draw(self, surf, globex, globey):
        f = self.facing
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (f*50,
                                 self.animation_counter*50,
                                 50,50))

    def move(self, rocks):
        for rock in rocks:
            if self.rect.colliderect(rock.rect):
                if self.rect.centerx <= rock.rect.centerx:
                    self.rect.centerx -= 1
                    self.rect.centery += 1
                else:
                    self.rect.centerx += 1
                    self.rect.centery += 1

                if self.rect.centery <= rock.rect.centery:
                    self.rect.centery -= 1
                    self.rect.centerx += 1
                else:
                    self.rect.centery += 1
                    self.rect.centerx += 1
            else:
                pass
            
        if self.goto[0] < self.rect.left:
            if self.goto[1] < self.rect.top:
                self.facing = 13#up-left
            elif self.goto[1] > self.rect.top:
                self.facing = 1#down-left
            else:
                self.facing = 15#left
        elif self.goto[0] > self.rect.left:
            if self.goto[1] < self.rect.top:
                self.facing = 9#up-right
            elif self.goto[1] > self.rect.top:
                self.facing = 5#down-right
            else:
                self.facing = 7#right
        else:
            if self.goto[1] < self.rect.top:
                self.facing = 11#up
            elif self.goto[1] > self.rect.top:
                self.facing = 3#down
            else:pass#pass

        if self.rect.left < self.goto[0]:
            self.rect.left += 1
        elif self.rect.left > self.goto[0]:
            self.rect.left -= 1

        if self.rect.top < self.goto[1]:
            self.rect.top += 1
        elif self.rect.top > self.goto[1]:
            self.rect.top -= 1

        if self.rect.centerx - self.goto[0] <= 50 and self.rect.centerx - self.goto[0] >= -50:
            self.goto = [random.randint(0,40*50-1), random.randint(0,40*50-1)]
        if self.rect.centery - self.goto[1] <= 50 and self.rect.centery - self.goto[1] >= -50:
            self.goto = [random.randint(0,40*50-1), random.randint(0,40*50-1)]
            
    def update(self, rocks):
        self.move(rocks)
                
        self.master_counter += 1
        if self.master_counter == 3: 
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0               



#attacks
class PenguinAttack(pygame.sprite.Sprite):
    def __init__(self, locs, enemy):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('penguin_attack.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.should_move = True

        self.duration = 0
        self.damage_counter = 0
        self.damage = 1,3
        self.detonate = False

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0
        self.goto = [enemy.rect.left, enemy.rect.top]

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+50,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self, rocks):
        self.on_animation = "moving"
        if self.rect.left - self.goto[0] <= 250 and self.rect.left - self.goto[0] >= -250:
            if self.rect.top - self.goto[1] <= 250 and self.rect.top - self.goto[1] >= -250:
                for rock in rocks:
                    if self.rect.colliderect(rock.rect):
                        if self.rect.centerx <= rock.rect.centerx:
                            self.rect.centerx -= 1
                            self.rect.centery += 1
                        else:
                            self.rect.centerx += 1
                            self.rect.centery += 1

                        if self.rect.centery <= rock.rect.centery:
                            self.rect.centery -= 1
                            self.rect.centerx += 1
                        else:
                            self.rect.centery += 1
                            self.rect.centerx += 1
                    else:
                        pass
                    
                if self.goto[0] < self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 13#up-left
                    elif self.goto[1] > self.rect.top:
                        self.facing = 1#down-left
                    else:
                        self.facing = 15#left
                elif self.goto[0] > self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 9#up-right
                    elif self.goto[1] > self.rect.top:
                        self.facing = 5#down-right
                    else:
                        self.facing = 7#right
                else:
                    if self.goto[1] < self.rect.top:
                        self.facing = 11#up
                    elif self.goto[1] > self.rect.top:
                        self.facing = 3#down
                    else:pass#pass

                if self.rect.left < self.goto[0]:
                    self.rect.left += 1
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 1

                if self.rect.top < self.goto[1]:
                    self.rect.top += 1
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 1

                if self.rect.left < self.goto[0]:
                    self.rect.left += 1
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 1

                if self.rect.top < self.goto[1]:
                    self.rect.top += 1
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 1

                if self.rect.left == self.goto[0]:
                    if self.rect.top == self.goto[1]:
                        self.on_animation = "still"
            else:
                self.on_animation = "still"
        else:
            self.on_animation = "still"
            
    def update(self, player):
        self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0

class PenguinTorpedo(pygame.sprite.Sprite):
    def __init__(self, locs, enemy):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('player_torpedo.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.should_move = True

        self.duration = 0
        self.damage_counter = 0
        self.damage = 5,15
        self.detonate = True

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0
        self.goto = [enemy.rect.left, enemy.rect.top]

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self, rocks):
        self.on_animation = "moving"
        if self.rect.left - self.goto[0] <= 250 and self.rect.left - self.goto[0] >= -250:
            if self.rect.top - self.goto[1] <= 250 and self.rect.top - self.goto[1] >= -250:
                for rock in rocks:
                    if self.rect.colliderect(rock.rect):
                        if self.rect.centerx <= rock.rect.centerx:
                            self.rect.centerx -= 2
                            self.rect.centery += 2
                        else:
                            self.rect.centerx += 2
                            self.rect.centery += 2

                        if self.rect.centery <= rock.rect.centery:
                            self.rect.centery -= 2
                            self.rect.centerx += 2
                        else:
                            self.rect.centery += 2
                            self.rect.centerx += 2
                    else:
                        pass
                    
                if self.goto[0] < self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 13#up-left
                    elif self.goto[1] > self.rect.top:
                        self.facing = 1#down-left
                    else:
                        self.facing = 15#left
                elif self.goto[0] > self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 9#up-right
                    elif self.goto[1] > self.rect.top:
                        self.facing = 5#down-right
                    else:
                        self.facing = 7#right
                else:
                    if self.goto[1] < self.rect.top:
                        self.facing = 11#up
                    elif self.goto[1] > self.rect.top:
                        self.facing = 3#down
                    else:pass#pass

                if self.rect.left < self.goto[0]:
                    self.rect.left += 2
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 2

                if self.rect.top < self.goto[1]:
                    self.rect.top += 2
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 2

                if self.rect.left < self.goto[0]:
                    self.rect.left += 2
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 2

                if self.rect.top < self.goto[1]:
                    self.rect.top += 2
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 2

                if self.rect.left == self.goto[0]:
                    if self.rect.top == self.goto[1]:
                        self.on_animation = "still"
            else:
                self.on_animation = "still"
        else:
            self.on_animation = "still"
            
    def update(self, player):
        #self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0


class PenguinLockTorpedo(pygame.sprite.Sprite):
    def __init__(self, locs, enemy):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('homing-yellow.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.should_move = True

        self.duration = 0
        self.damage_counter = 0
        self.damage = 4,12
        self.detonate = True

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0
        self.goto = [enemy.rect.left, enemy.rect.top]

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self, rocks):
        self.on_animation = "moving"
        if self.rect.left - self.goto[0] <= 250 and self.rect.left - self.goto[0] >= -250:
            if self.rect.top - self.goto[1] <= 250 and self.rect.top - self.goto[1] >= -250:
                for rock in rocks:
                    if self.rect.colliderect(rock.rect):
                        if self.rect.centerx <= rock.rect.centerx:
                            self.rect.centerx -= 2
                            self.rect.centery += 2
                        else:
                            self.rect.centerx += 2
                            self.rect.centery += 2

                        if self.rect.centery <= rock.rect.centery:
                            self.rect.centery -= 2
                            self.rect.centerx += 2
                        else:
                            self.rect.centery += 2
                            self.rect.centerx += 2
                    else:
                        pass
                    
                if self.goto[0] < self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 13#up-left
                    elif self.goto[1] > self.rect.top:
                        self.facing = 1#down-left
                    else:
                        self.facing = 15#left
                elif self.goto[0] > self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 9#up-right
                    elif self.goto[1] > self.rect.top:
                        self.facing = 5#down-right
                    else:
                        self.facing = 7#right
                else:
                    if self.goto[1] < self.rect.top:
                        self.facing = 11#up
                    elif self.goto[1] > self.rect.top:
                        self.facing = 3#down
                    else:pass#pass

                if self.rect.left < self.goto[0]:
                    self.rect.left += 2
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 2

                if self.rect.top < self.goto[1]:
                    self.rect.top += 2
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 2

                if self.rect.left < self.goto[0]:
                    self.rect.left += 2
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 2

                if self.rect.top < self.goto[1]:
                    self.rect.top += 2
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 2

                if self.rect.left == self.goto[0]:
                    if self.rect.top == self.goto[1]:
                        self.on_animation = "still"
            else:
                self.on_animation = "still"
        else:
            self.on_animation = "still"
            
    def update(self, player):
        self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0


class HerringTorpedo(pygame.sprite.Sprite):
    def __init__(self, locs, enemy):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('herring-torpedo.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.should_move = True

        self.duration = 0
        self.damage_counter = 0
        self.damage = 5,15
        self.detonate = True

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0
        self.goto = [enemy.rect.left, enemy.rect.top]

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self, rocks):
        self.on_animation = "moving"
        if self.rect.left - self.goto[0] <= 250 and self.rect.left - self.goto[0] >= -250:
            if self.rect.top - self.goto[1] <= 250 and self.rect.top - self.goto[1] >= -250:
                for rock in rocks:
                    if self.rect.colliderect(rock.rect):
                        if self.rect.centerx <= rock.rect.centerx:
                            self.rect.centerx -= 2
                            self.rect.centery += 2
                        else:
                            self.rect.centerx += 2
                            self.rect.centery += 2

                        if self.rect.centery <= rock.rect.centery:
                            self.rect.centery -= 2
                            self.rect.centerx += 2
                        else:
                            self.rect.centery += 2
                            self.rect.centerx += 2
                    else:
                        pass
                    
                if self.goto[0] < self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 13#up-left
                    elif self.goto[1] > self.rect.top:
                        self.facing = 1#down-left
                    else:
                        self.facing = 15#left
                elif self.goto[0] > self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 9#up-right
                    elif self.goto[1] > self.rect.top:
                        self.facing = 5#down-right
                    else:
                        self.facing = 7#right
                else:
                    if self.goto[1] < self.rect.top:
                        self.facing = 11#up
                    elif self.goto[1] > self.rect.top:
                        self.facing = 3#down
                    else:pass#pass

                if self.rect.left < self.goto[0]:
                    self.rect.left += 2
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 2

                if self.rect.top < self.goto[1]:
                    self.rect.top += 2
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 2

                if self.rect.left < self.goto[0]:
                    self.rect.left += 2
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 2

                if self.rect.top < self.goto[1]:
                    self.rect.top += 2
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 2

                if self.rect.left == self.goto[0]:
                    if self.rect.top == self.goto[1]:
                        self.on_animation = "still"
            else:
                self.on_animation = "still"
        else:
            self.on_animation = "still"
            
    def update(self, player):
        #self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0

            
class PiranhaAttack(pygame.sprite.Sprite):
    def __init__(self, locs, enemy):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('piranha-attack.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.duration = 0
        self.damage_counter = 0
        self.damage = 1,2

        self.detonate = False

        self.hitpoints = 2

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0
        self.goto = [enemy.rect.left, enemy.rect.top]
        self.move_counter = 0

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+50,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self, rocks):
        self.on_animation = "moving"
        if self.rect.left - self.goto[0] <= 200 and self.rect.left - self.goto[0] >= -200:
            if self.rect.top - self.goto[1] <= 200 and self.rect.top - self.goto[1] >= -200:
                for rock in rocks:
                    if self.rect.colliderect(rock.rect):
                        if self.rect.centerx <= rock.rect.centerx:
                            self.rect.centerx -= 1
                            self.rect.centery += 1
                        else:
                            self.rect.centerx += 1
                            self.rect.centery += 1

                        if self.rect.centery <= rock.rect.centery:
                            self.rect.centery -= 1
                            self.rect.centerx += 1
                        else:
                            self.rect.centery += 1
                            self.rect.centerx += 1
                    else:
                        pass
                    
                if self.goto[0] < self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 13#up-left
                    elif self.goto[1] > self.rect.top:
                        self.facing = 1#down-left
                    else:
                        self.facing = 15#left
                elif self.goto[0] > self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 9#up-right
                    elif self.goto[1] > self.rect.top:
                        self.facing = 5#down-right
                    else:
                        self.facing = 7#right
                else:
                    if self.goto[1] < self.rect.top:
                        self.facing = 11#up
                    elif self.goto[1] > self.rect.top:
                        self.facing = 3#down
                    else:pass#pass

                if self.rect.left < self.goto[0]:
                    self.rect.left += 1
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 1

                if self.rect.top < self.goto[1]:
                    self.rect.top += 1
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 1

                if self.rect.left < self.goto[0]:
                    self.rect.left += 1
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 1

                if self.rect.top < self.goto[1]:
                    self.rect.top += 1
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 1

                if self.rect.left == self.goto[0]:
                    if self.rect.top == self.goto[1]:
                        self.on_animation = "still"
            else:
                self.on_animation = "still"
        else:
            self.on_animation = "still"
            
    def update(self, player):
        self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0


class SharkAttack(pygame.sprite.Sprite):
    def __init__(self, locs, enemy):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('sharky.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.duration = 0
        self.damage_counter = 0

        self.hitpoints = 2
        self.damage = 2,4

        self.detonate = False

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0
        self.goto = [enemy.rect.left, enemy.rect.top]
        self.move_counter = 0

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+50,
                                     50,50))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self, rocks):
        self.on_animation = "moving"
        if self.rect.left - self.goto[0] <= 200 and self.rect.left - self.goto[0] >= -200:
            if self.rect.top - self.goto[1] <= 200 and self.rect.top - self.goto[1] >= -200:
                for rock in rocks:
                    if self.rect.colliderect(rock.rect):
                        if self.rect.centerx <= rock.rect.centerx:
                            self.rect.centerx -= 1
                            self.rect.centery += 1
                        else:
                            self.rect.centerx += 1
                            self.rect.centery += 1

                        if self.rect.centery <= rock.rect.centery:
                            self.rect.centery -= 1
                            self.rect.centerx += 1
                        else:
                            self.rect.centery += 1
                            self.rect.centerx += 1
                    else:
                        pass
                    
                if self.goto[0] < self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 13#up-left
                    elif self.goto[1] > self.rect.top:
                        self.facing = 1#down-left
                    else:
                        self.facing = 15#left
                elif self.goto[0] > self.rect.left:
                    if self.goto[1] < self.rect.top:
                        self.facing = 9#up-right
                    elif self.goto[1] > self.rect.top:
                        self.facing = 5#down-right
                    else:
                        self.facing = 7#right
                else:
                    if self.goto[1] < self.rect.top:
                        self.facing = 11#up
                    elif self.goto[1] > self.rect.top:
                        self.facing = 3#down
                    else:pass#pass

                if self.rect.left < self.goto[0]:
                    self.rect.left += 1
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 1

                if self.rect.top < self.goto[1]:
                    self.rect.top += 1
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 1

                if self.rect.left < self.goto[0]:
                    self.rect.left += 1
                elif self.rect.left > self.goto[0]:
                    self.rect.left -= 1

                if self.rect.top < self.goto[1]:
                    self.rect.top += 1
                elif self.rect.top > self.goto[1]:
                    self.rect.top -= 1

                if self.rect.left == self.goto[0]:
                    if self.rect.top == self.goto[1]:
                        self.on_animation = "still"
            else:
                self.on_animation = "still"
        else:
            self.on_animation = "still"
            
    def update(self, player):
        self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0


#rocks/ambience
class Rock(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('rocks.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50
        self.small_rect = pygame.rect.Rect(0,0,35,35)
        self.small_rect.center = (self.rect.center[0] + 5, self.rect.center[1] + 2)
        self.num = random.randint(0,4)
        if self.num == 5:
            self.num = 4
            

    def draw(self, surf, globex, globey):
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (self.num*50,
                                 0,
                                 50,50))

class Seaweed(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('seaweed.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0] * 50
        self.rect.top = locs[1] * 50
        self.small_rect = pygame.rect.Rect(0,0,35,35)
        self.small_rect.center = (self.rect.center[0] + 5, self.rect.center[1] + 2)
        self.num = random.randint(0,3)
        if self.num == 4:
            self.num = 3
            

    def draw(self, surf, globex, globey):
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (self.num*50,
                                 0,
                                 50,50))

class Explosion(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('explosion.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]
        self.counter = 0
        self.num = 0
        self.ended = False
            

    def draw(self, surf, globex, globey):
        self.counter += 1
        if self.counter == 2:
            self.num += 1
            self.counter = 0
        if self.num == 10:
            self.ended = True
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (self.num*50,
                                 0,
                                 50,50))

class SharkEat(pygame.sprite.Sprite):
    def __init__(self, locs):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('sharky.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]
        self.counter = 0
        self.num = 0
        self.ended = False
            

    def draw(self, surf, globex, globey):
        self.counter += 1
        if self.counter == 4:
            self.num += 1
            self.counter = 0
        if self.num == 10:
            self.ended = True
        surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                (0,
                                 self.num*50+200,
                                 50,50))




#harvesters
class PenguinHarvester(pygame.sprite.Sprite):
    def __init__(self, locs, neuts):
        pygame.sprite.Sprite.__init__(self)
        self.images, self.rects = load_image('penguin_harvester.png', alpha = True)
        self.net, r = load_image('net.png', alpha = True)
        self.rect = pygame.rect.Rect(0,0,50,50)
        self.rect.left = locs[0]
        self.rect.top = locs[1]

        self.duration = 0
        self.damage_counter = 0

        self.facing = 0
        self.rotate_timer = 4
        self.animation_counter = 0
        self.master_counter = 0

        self.have_fish = False
        self.goto = None
        
        self.closest_neut = None
        self.goto_neut = None
        if neuts:
            for neut in neuts:
                #need to find the closest one!
                posx = neut.rect.left
                posy = neut.rect.top
                if self.rect.left - posx <= 200 and self.rect.left - posx >= -200:
                    if self.rect.top - posy <= 200 and self.rect.top - posy >= -200:
                        self.closest_neut = neut
                        self.goto_neut = [self.closest_neut.rect.left, self.closest_neut.rect.top]
            self.goto = self.goto_neut
        else:
            if not self.goto_neut:self.goto_neut = [self.rect.left, self.rect.top]
            self.goto = self.goto_neut

        self.on_animation = 'still'

    def draw(self, surf, globex, globey):
        f = self.facing
        if self.on_animation == 'still':
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     0,
                                     50,50))
        elif self.on_animation == 'moving':
            if self.have_fish == False:
                surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                        (f*50,
                                         self.animation_counter*50+50,
                                         50,50))
            else:
                surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                        (f*50,
                                         self.animation_counter*50+50,
                                         50,50))
                surf.blit(self.net, (self.rect.left+globex, self.rect.top + globey))
        else:
            surf.blit(self.images, (self.rect.left+globex, self.rect.top + globey),
                                    (f*50,
                                     self.animation_counter*50+200,
                                     50,50))

    def move(self):
        self.on_animation = "moving"
            
        if self.goto[0] < self.rect.left:
            if self.goto[1] < self.rect.top:
                self.facing = 13#up-left
            elif self.goto[1] > self.rect.top:
                self.facing = 1#down-left
            else:
                self.facing = 15#left
        elif self.goto[0] > self.rect.left:
            if self.goto[1] < self.rect.top:
                self.facing = 9#up-right
            elif self.goto[1] > self.rect.top:
                self.facing = 5#down-right
            else:
                self.facing = 7#right
        else:
            if self.goto[1] < self.rect.top:
                self.facing = 11#up
            elif self.goto[1] > self.rect.top:
                self.facing = 3#down
            else:pass#pass

        if self.rect.left < self.goto[0]:
            self.rect.left += 1
        elif self.rect.left > self.goto[0]:
            self.rect.left -= 1

        if self.rect.top < self.goto[1]:
            self.rect.top += 1
        elif self.rect.top > self.goto[1]:
            self.rect.top -= 1

        if self.rect.left < self.goto[0]:
            self.rect.left += 1
        elif self.rect.left > self.goto[0]:
            self.rect.left -= 1

        if self.rect.top < self.goto[1]:
            self.rect.top += 1
        elif self.rect.top > self.goto[1]:
            self.rect.top -= 1

        if self.rect.left == self.goto[0]:
            if self.rect.top == self.goto[1]:
                self.on_animation = "still"
            
    def update(self, player):
        if self.have_fish == False:
            self.goto = self.goto_neut
        else:
            self.goto = [player.rect.left, player.rect.top]
        self.duration += 1
        self.master_counter += 1
        if self.master_counter == 4:
            self.animation_counter += 1
            if self.animation_counter == 3:
                self.animation_counter = 0
            self.master_counter = 0
